summaryrefslogtreecommitdiffstats
path: root/korn/dcop_proto.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/dcop_proto.h')
-rw-r--r--korn/dcop_proto.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/korn/dcop_proto.h b/korn/dcop_proto.h
index 18e01e99..defcf0c2 100644
--- a/korn/dcop_proto.h
+++ b/korn/dcop_proto.h
@@ -24,7 +24,7 @@
class AccountInput;
class TDEConfigGroup;
-class KIO_Protocol;
+class TDEIO_Protocol;
class KMailDrop;
class Protocol;
@@ -106,12 +106,12 @@ public:
//Functions that return a derived class.
//This way, no explicit cast is needed
/**
* This function returns a cast to a KIO_Protocol. Because this isn't a KIO_Protocol,
* it returns 0.
*
* @return 0
*/
- virtual const KIO_Protocol* getKIOProtocol() const { return 0; }
+ virtual const TDEIO_Protocol* getKIOProtocol() const { return 0; }
};
#endif
@@ -106,12 +106,12 @@ public:
//This way, no explicit cast is needed
/**
- * This function returns a cast to a KIO_Protocol. Because this isn't a KIO_Protocol,
+ * This function returns a cast to a TDEIO_Protocol. Because this isn't a TDEIO_Protocol,
* it returns 0.
*